==> huawei_iap-5.0.2%2B301.tar.gz: lib/model/ConsumeOwnedPurchaseResult.dart <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
import 'dart:convert' show json;

import 'ConsumePurchaseData.dart';
import 'Status.dart';

class ConsumeOwnedPurchaseResult {
  ConsumePurchaseData consumePurchaseData;
  String dataSignature;
  String errMsg;
  String returnCode;
  Status status;
  String rawValue;

  ConsumeOwnedPurchaseResult({
    this.consumePurchaseData,
    this.dataSignature,
    this.errMsg,
    this.returnCode,
    this.status,
    this.rawValue,
  });

  factory ConsumeOwnedPurchaseResult.fromJson(String source) =>
      ConsumeOwnedPurchaseResult.fromMap(source);

  String toJson() => json.encode(toMap());

  factory ConsumeOwnedPurchaseResult.fromMap(String source) {
    Map<String, dynamic> jsonMap = json.decode(source);
    return ConsumeOwnedPurchaseResult(
      consumePurchaseData: jsonMap["consumePurchaseData"] == null
          ? null
          : ConsumePurchaseData.fromJson(jsonMap["consumePurchaseData"]),
      dataSignature:
          jsonMap["dataSignature"] == null ? null : jsonMap["dataSignature"],
      errMsg: jsonMap["errMsg"] == null ? null : jsonMap["errMsg"],
      returnCode: jsonMap["returnCode"] == null
          ? null
          : jsonMap["returnCode"].toString(),
      status:
          jsonMap["status"] == null ? null : Status.fromMap(jsonMap["status"]),
      rawValue: source,
    );
  }

  Map<String, dynamic> toMap() => {
        "consumePurchaseData":
            consumePurchaseData == null ? null : consumePurchaseData.toJson(),
        "dataSignature": dataSignature,
        "errMsg": errMsg,
        "returnCode": returnCode,
        "status": status == null ? null : status.toMap(),
      };

  @override
  bool operator ==(Object o) {
    if (identical(this, o)) return true;
    if (runtimeType != o.runtimeType) return false;
    final ConsumeOwnedPurchaseResult check = o;
    return o is ConsumeOwnedPurchaseResult &&
        check.consumePurchaseData == consumePurchaseData &&
        check.dataSignature == dataSignature &&
        check.errMsg == errMsg &&
        check.returnCode == returnCode &&
        check.status == status;
  }

  @override
  int get hashCode =>
      consumePurchaseData.hashCode ^
      dataSignature.hashCode ^
      errMsg.hashCode ^
      returnCode.hashCode ^
      status.hashCode;
}

==> huawei_iap-6.4.0%2B301.tar.gz: lib/model/ConsumeOwnedPurchaseResult.dart <==
/*
    Copyright 2020-2022. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

import 'dart:convert' show json;

import 'ConsumePurchaseData.dart';
import 'Status.dart';

/// Information returned when the consumeOwnedPurchase API is successfully called.
class ConsumeOwnedPurchaseResult {
  ConsumePurchaseData? consumePurchaseData;
  String? dataSignature;
  String? errMsg;
  String? returnCode;
  Status? status;
  String? signatureAlgorithm;
  String rawValue;

  ConsumeOwnedPurchaseResult({
    this.consumePurchaseData,
    this.dataSignature,
    this.errMsg,
    this.returnCode,
    this.status,
    this.signatureAlgorithm,
    required this.rawValue,
  });

  factory ConsumeOwnedPurchaseResult.fromJson(String source) =>
      ConsumeOwnedPurchaseResult.fromMap(source);

  String toJson() => json.encode(toMap());

  factory ConsumeOwnedPurchaseResult.fromMap(String source) {
    Map<String, dynamic> jsonMap = json.decode(source);
    return ConsumeOwnedPurchaseResult(
      consumePurchaseData: jsonMap["consumePurchaseData"] == null
          ? null
          : ConsumePurchaseData.fromJson(jsonMap["consumePurchaseData"]),
      dataSignature:
          jsonMap["dataSignature"] == null ? null : jsonMap["dataSignature"],
      errMsg: jsonMap["errMsg"] == null ? null : jsonMap["errMsg"],
      returnCode: jsonMap["returnCode"] == null
          ? null
          : jsonMap["returnCode"].toString(),
      status:
          jsonMap["status"] == null ? null : Status.fromMap(jsonMap["status"]),
      signatureAlgorithm: jsonMap["signatureAlgorithm"] == null
          ? null
          : jsonMap["signatureAlgorithm"],
      rawValue: source,
    );
  }

  Map<String, dynamic> toMap() => {
        "consumePurchaseData":
            consumePurchaseData == null ? null : consumePurchaseData!.toJson(),
        "dataSignature": dataSignature,
        "errMsg": errMsg,
        "returnCode": returnCode,
        "status": status == null ? null : status!.toMap(),
        "signatureAlgorithm": signatureAlgorithm,
      };

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;
    if (this.runtimeType != other.runtimeType) return false;

    return other is ConsumeOwnedPurchaseResult &&
        this.consumePurchaseData == other.consumePurchaseData &&
        this.dataSignature == other.dataSignature &&
        this.errMsg == other.errMsg &&
        this.returnCode == other.returnCode &&
        this.status == other.status &&
        this.signatureAlgorithm == other.signatureAlgorithm;
  }

  @override
  int get hashCode =>
      consumePurchaseData.hashCode ^
      dataSignature.hashCode ^
      errMsg.hashCode ^
      returnCode.hashCode ^
      status.hashCode ^
      signatureAlgorithm.hashCode;
}
